@@ -94,11 +94,12 @@ typedef struct _el_win
     int      days;        /* how many extra days to show; usually 0 */
     el_page  page;        /* appointment page to show */
     char     time_now[6]; /* hh:mm */
-    char     date_now[XFICAL_APPT_TIME_FORMAT_LEN]; /* yyyymmddThhmmss */
+
+    GDateTime *date_now;
     GList    *apptw_list; /* keep track of appointments being updated */
 } el_win; /* event list window */
 
-el_win* create_el_win(const gchar *start_date);
+el_win* create_el_win (GDateTime *gdt);
 void refresh_el_win(el_win *el);
 
 #endif /* !__EVENT_LIST_H__ */
