@@ -21,17 +21,13 @@
 
  */
 
-#ifndef __ORAGE_FUNCTIONS_H__
-#define __ORAGE_FUNCTIONS_H__
+#ifndef ORAGE_FUNCTIONS_H
+#define ORAGE_FUNCTIONS_H
 
-#define CALENDAR_RUNNING "_XFCE_CALENDAR_RUNNING"
-#define CALENDAR_TOGGLE_EVENT "_XFCE_CALENDAR_TOGGLE_HERE"
-
-#define XFICAL_APPT_TIME_FORMAT "%04d%02d%02dT%02d%02d%02d"
-#define XFICAL_APPT_TIME_FORMAT_LEN 16
-#define XFICAL_APPT_DATE_FORMAT "%04d%02d%02d"
-#define XFICAL_APPT_DATE_FORMAT_LEN 9
+#include <glib.h>
+#include <gtk/gtk.h>
 
+#define ORAGE_APP_ID "org.xfce.orage"
 #define ORAGE_DIR "orage" G_DIR_SEPARATOR_S
 #define ORAGE_PAR_FILE  "oragerc"
 #define ORAGE_PAR_DIR_FILE ORAGE_DIR ORAGE_PAR_FILE
@@ -48,22 +44,14 @@
 
 #define ORAGE_STR_EXISTS(str) ((str != NULL) && (str[0] != 0))
 
-typedef struct _OrageRc
-{
-    GKeyFile *rc;
-    gboolean read_only;
-    gchar *file_name;
-    gchar *cur_group;
-} OrageRc;
+#define DATE_KEY "button-date"
 
 #if 0
 void program_log (const char *format, ...);
 #endif
 
 GtkWidget *orage_create_combo_box_with_content(const gchar *text[], int size);
-
-gboolean orage_date_button_clicked(GtkWidget *button, GtkWidget *win);
-
+gboolean orage_date_button_clicked (GtkWidget *button, GtkWidget *win);
 gboolean orage_exec(const gchar *cmd, gboolean *cmd_active, GError **error);
 
 GtkWidget *orage_toolbar_append_button (GtkWidget *toolbar,
@@ -86,67 +74,73 @@ GtkWidget *orage_menu_item_new_with_mnemonic(const gchar *label
 
 char *orage_replace_text(char *text, char *old, char *new);
 char *orage_limit_text(char *text, int max_line_len, int max_lines);
-char *orage_process_text_commands(char *text);
+gchar *orage_process_text_commands (const gchar *text);
 
 GtkWidget *orage_period_hbox_new(gboolean head_space, gboolean tail_space
         , GtkWidget *spin_dd, GtkWidget *dd_label
         , GtkWidget *spin_hh, GtkWidget *hh_label
         , GtkWidget *spin_mm, GtkWidget *mm_label);
 
-struct tm *orage_localtime();
-char *orage_localdate_i18();
-struct tm orage_i18_time_to_tm_time(const gchar *i18_time);
-struct tm orage_i18_date_to_tm_date(const gchar *i18_date);
-gchar *orage_i18_time_to_icaltime(const gchar *i18_time);
-gchar *orage_i18_date_to_icaldate(const gchar *i18_date);
-gchar *orage_tm_time_to_i18_time(struct tm *tm_date);
-gchar *orage_tm_date_to_i18_date(const struct tm *tm_date);
-gchar *orage_tm_time_to_icaltime(struct tm *t);
-struct tm orage_icaltime_to_tm_time(const gchar *i18_date, gboolean real_tm);
-char *orage_icaltime_to_i18_time(const char *icaltime);
-char *orage_icaltime_to_i18_time_only(const char *icaltime);
-struct tm orage_cal_to_tm_time(GtkCalendar *cal, gint hh, gint mm);
-char *orage_cal_to_i18_time(GtkCalendar *cal, gint hh, gint mm);
-char *orage_cal_to_i18_date(GtkCalendar *cal);
-char *orage_cal_to_icaldate(GtkCalendar *cal);
-void orage_move_day(struct tm *t, int day);
-gint orage_days_between (const struct tm *t1, const struct tm *t2);
+void orage_gdatetime_unref (GDateTime *gdt);
+gchar *orage_gdatetime_to_i18_time (GDateTime *gdt, gboolean date_only);
 
-void orage_select_date(GtkCalendar *cal, guint year, guint month, guint day);
+/** Create ical time string. Unlike g_date_time_format this function add padding
+ *  with '0' to year value. Padding is required by Ical format.
+ *  @note This function should not used for Orage internal date/time, use
+ *        GDateTime instead. It is intended only for exporting GDateTime.
+ *  @param gdt GDateTime
+ *  @param date_only, when true returns date string in format yyyymmdd, if false
+ *         return date and time in format yyyymmddThhmmss.
+ *  @return date or time sting. User must free returned string.
+ */
+gchar *orage_gdatetime_to_icaltime (GDateTime *gdt, gboolean date_only);
+
+/** Comapare dates only.
+ *  @param gdt1 GDateTime fist date and time
+ *  @param gdt2 GDateTime second date and time
+ *  @return 0 if dates are equal, -1 if gdt1 is less than gdt2, 1 if gdt1 is
+ *  larger than gdt2.
+ */
+gint orage_gdatetime_compare_date (GDateTime *gdt1, GDateTime *gdt2);
+
+/** Convert icaltime to GDateTime.
+ *  @note This function should not used for Orage internal date/time, use
+ *        GDateTime instead. It is intended only for importing Ical date/time.
+ *  @param i18_date date and time in icaltime format.
+ *  @return GDateTime or NULL if input string does not contain date/time
+ *          information
+ */
+GDateTime *orage_icaltime_to_gdatetime (const gchar *i18_date);
+
+/** Return GDateTime from GTK calendar. This function set hour and minute values
+ *  as well.
+ *  @param cal instance of GTK calendar
+ *  @param hh hour value
+ *  @param mm minute value
+ *  @return GDateTime, user should release return by g_date_time_unref.
+ */
+GDateTime *orage_cal_to_gdatetime (GtkCalendar *cal, gint hh, gint mm);
+
+/** Find number of days between two time values.
+ *  @param gdt1 first time value
+ *  @param gdt2 second time value
+ *  @return Number of days between two time value. This value can be negative if
+ *          gdt2 < gdt1
+ */
+gint orage_gdatetime_days_between (GDateTime *gdt1, GDateTime *gdt2);
+
+/** Set (GTK) calendar to selected date.
+ *  @param cal instance of GTK calendar
+ *  @param gdt selected date.
+ */
+void orage_select_date (GtkCalendar *cal, GDateTime *gdt);
 void orage_select_today(GtkCalendar *cal);
 
 gboolean orage_copy_file (const gchar *source, const gchar *target);
 gchar *orage_data_file_location(const gchar *dir_name);
 gchar *orage_config_file_location (const gchar *dir_name);
 
-OrageRc *orage_rc_file_open(const gchar *fpath, gboolean read_only);
-void orage_rc_file_close(OrageRc *orc);
-gchar **orage_rc_get_groups(OrageRc *orc);
-void orage_rc_set_group(OrageRc *orc, const gchar *grp);
-void orage_rc_del_group(OrageRc *orc, const gchar *grp);
-gchar *orage_rc_get_group(OrageRc *orc);
-gchar *orage_rc_get_str(OrageRc *orc, const gchar *key, const gchar *def);
-gint   orage_rc_get_int(OrageRc *orc, const gchar *key, gint def);
-gboolean orage_rc_get_bool(OrageRc *orc, const gchar *key, gboolean def);
-void orage_rc_put_str(OrageRc *orc, const gchar *key, const gchar *val);
-void orage_rc_put_int(OrageRc *orc, const gchar *key, gint val);
-void orage_rc_put_bool(OrageRc *orc, const gchar *key, gboolean val);
-gboolean orage_rc_exists_item(OrageRc *orc, const gchar *key);
-void orage_rc_del_item(OrageRc *orc, const gchar *key);
-
-/** Read RGBA colour from configuration file.
- *  described in orage rc, then if colour is not
- *  @param orc Orage RC file refernce
- *  @param key key for colour
- *  @param rgba output colour.
- *  @param def default colour. This colour is used only when colour is not
- *         present or not pareseable in given rc file.
- *  @retrun true when output rgba is updated, false if output not updated.
- */
-gboolean orage_rc_read_color (OrageRc *orc, const gchar *key,
-                              GdkRGBA *rgba, const gchar *def);
-
-gint orage_info_dialog (GtkWindow *parent, const gchar *primary_text,
+void orage_info_dialog (GtkWindow *parent, const gchar *primary_text,
                                            const gchar *secondary_text);
 
 gint orage_warning_dialog (GtkWindow *parent, const gchar *primary_text,
@@ -154,16 +148,18 @@ gint orage_warning_dialog (GtkWindow *parent, const gchar *primary_text,
                                               const gchar *no_text,
                                               const gchar *yes_text);
 
-gint orage_error_dialog (GtkWindow *parent, const gchar *primary_text,
+void orage_error_dialog (GtkWindow *parent, const gchar *primary_text,
                                             const gchar *secondary_text);
 
 GtkWidget *orage_create_framebox_with_content (const gchar *title,
                                                GtkShadowType shadow_type,
                                                GtkWidget *content);
 
-/* NOTE: the following is in main.c */
+/* NOTE: the followings two function are implemented in main.c */
 void orage_toggle_visible(void);
+void orage_quit (void);
 
+#ifdef HAVE_X11_TRAY_ICON
 /* This is wrapper for deprecated 'gtk_status_icon_is_embedded', it is used only
  * for suppress deprecated warning message.
  */
@@ -185,7 +181,7 @@ GtkStatusIcon *orage_status_icon_new_from_pixbuf (GdkPixbuf *pixbuf);
  */
 void orage_status_icon_set_tooltip_markup (GtkStatusIcon *status_icon,
                                            const gchar *markup);
-
+#endif
 /** Create button with image. This code is taken from Mousepad.
  *
  *  @note This function is direct replacement for gtk_button_new_from_stock.
@@ -204,8 +200,14 @@ GtkWidget *orage_util_image_button (const gchar *icon_name, const gchar *label);
  *  @return true when rgba was successfully updated, false color_str or def was
  *         invalid
  */
-gboolean orgage_str_to_rgba (const gchar *color_str,
+gboolean orage_str_to_rgba (const gchar *color_str,
                              GdkRGBA *rgba,
                              const gchar *def);
 
+/** Tests if debug messages are printed out.
+ *  @return true when debug messages is printed out, false if not.
+ */
+gboolean orage_is_debug_logging_enabled (void);
+
+
 #endif /* !__ORAGE_FUNCTIONS_H__ */
