@@ -445,7 +445,9 @@ gboolean orage_import_file (const gchar *entry_filename)
         return(FALSE);
 }
 
-gboolean orage_export_file(gchar *entry_filename, gint type, gchar *uids) 
+gboolean orage_export_file (const gchar *entry_filename,
+                            const gint type,
+                            const gchar *uids)
 {
     return(xfical_export_file(entry_filename, type, uids));
 }
@@ -577,9 +579,9 @@ static void orage_foreign_file_remove_line(gint del_line)
     xfical_alarm_build_list(FALSE);
 }
 
-gboolean orage_foreign_file_remove(gchar *filename)
+gboolean orage_foreign_file_remove (const gchar *filename)
 {
-    int i = 0;
+    gint i = 0;
     gboolean found = FALSE;
 
     if (interface_lock) {
@@ -587,17 +589,19 @@ gboolean orage_foreign_file_remove(gchar *filename)
         return(FALSE);
     }
     if (!ORAGE_STR_EXISTS(filename)) {
-        g_warning("File is empty. Not removed.");
+        g_warning("File '%s' is empty. Not removed.", filename);
         return(FALSE);
     }
     for (i = 0; i < g_par.foreign_count && !found; i++) {
+        g_warning("file '%s'", g_par.foreign_data[i].file);
+        g_warning("name '%s'", g_par.foreign_data[i].name);
         if (strcmp(g_par.foreign_data[i].file, filename) == 0 ||
             strcmp(g_par.foreign_data[i].name, filename) == 0) {
             found = TRUE;
         }
     }
     if (!found) {
-        g_warning("File not found. Not removed.");
+        g_warning("File '%s' not found. Not removed.", filename);
         return(FALSE);
     }
 
@@ -710,7 +714,7 @@ static gboolean orage_foreign_file_add_internal (const gchar *filename,
                    "New file not added.", G_STRFUNC);
         if (main_window)
         {
-            (void)orage_error_dialog(GTK_WINDOW(main_window)
+            orage_error_dialog (GTK_WINDOW (main_window)
                     , add_failed
                     , _("Orage can only handle 10 foreign files. Limit reached."));
         }
@@ -720,7 +724,7 @@ static gboolean orage_foreign_file_add_internal (const gchar *filename,
         g_warning ("%s: File is empty. New file not added.", G_STRFUNC);
         if (main_window)
         {
-            (void)orage_error_dialog(GTK_WINDOW(main_window)
+            orage_error_dialog (GTK_WINDOW (main_window)
                     , add_failed
                     , _("Filename is empty."));
         }
@@ -730,7 +734,7 @@ static gboolean orage_foreign_file_add_internal (const gchar *filename,
         g_warning ("%s: Name is empty. New file not added.", G_STRFUNC);
         if (main_window)
         {
-            (void)orage_error_dialog(GTK_WINDOW(main_window)
+            orage_error_dialog (GTK_WINDOW (main_window)
                     , add_failed
                     , _("Name is empty."));
         }
@@ -741,7 +745,7 @@ static gboolean orage_foreign_file_add_internal (const gchar *filename,
                    G_STRFUNC, filename);
         if (main_window)
         {
-            (void)orage_error_dialog(GTK_WINDOW(main_window)
+            orage_error_dialog (GTK_WINDOW (main_window)
                     , add_failed
                     , _("File does not exist."));
         }
@@ -753,7 +757,7 @@ static gboolean orage_foreign_file_add_internal (const gchar *filename,
                        G_STRFUNC);
             if (main_window)
             {
-                (void)orage_error_dialog(GTK_WINDOW(main_window)
+                orage_error_dialog (GTK_WINDOW (main_window)
                         , add_failed
                         , _("Same filename already exists in Orage."));
             }
@@ -764,7 +768,7 @@ static gboolean orage_foreign_file_add_internal (const gchar *filename,
                        "New file not added", G_STRFUNC);
             if (main_window)
             {
-                (void)orage_error_dialog(GTK_WINDOW(main_window)
+                orage_error_dialog (GTK_WINDOW (main_window)
                         , add_failed
                         , _("Same name already exists in Orage."));
             }
