@@ -46,7 +46,6 @@
 #include "appointment.h"
 #include "parameters.h"
 #include "tray_icon.h"
-#include "../globaltime/globaltime.h"
 
 #ifdef HAVE_LIBXFCE4UI
 #include <libxfce4ui/libxfce4ui.h>
@@ -98,12 +97,12 @@ static GtkWidget *orage_image_menu_item (const gchar *label,
 static void on_Today_activate (G_GNUC_UNUSED GtkMenuItem *menuitem,
                                gpointer user_data)
 {
-    struct tm *t;
+    GDateTime *gdt;
     CalWin *xfcal = (CalWin *)user_data;
 
-    t = orage_localtime();
-    orage_select_date(GTK_CALENDAR(xfcal->mCalendar), t->tm_year+1900
-            , t->tm_mon, t->tm_mday);
+    gdt = g_date_time_new_now_local ();
+    orage_select_date (GTK_CALENDAR (xfcal->mCalendar), gdt);
+    g_date_time_unref (gdt);
     (void)create_el_win (NULL);
 }
 
@@ -116,66 +115,18 @@ static void on_preferences_activate (G_GNUC_UNUSED GtkMenuItem *menuitem,
 static void on_new_appointment_activate (G_GNUC_UNUSED GtkMenuItem *menuitem,
                                          G_GNUC_UNUSED gpointer user_data)
 {
-    struct tm *t;
+    GDateTime *gdt;
     char cur_date[9];
+    gint year;
+    gint month;
+    gint day;
 
-    t = orage_localtime();
-    g_snprintf(cur_date, sizeof (cur_date), "%04d%02d%02d", t->tm_year+1900
-               , t->tm_mon+1, t->tm_mday);
-    create_appt_win("NEW", cur_date);
-}
+    gdt = g_date_time_new_now_local ();
+    g_date_time_get_ymd (gdt, &year, &month, &day);
+    g_snprintf (cur_date, sizeof (cur_date), "%04d%02d%02d", year, month, day);
 
-static void on_globaltime_activate (G_GNUC_UNUSED GtkMenuItem *menuitem,
-                                    G_GNUC_UNUSED gpointer user_data)
-{
-    GError *error = NULL;
-
-    if (!orage_exec("globaltime", NULL, &error))
-        g_message("%s: start of %s failed: %s", "Orage", "globaltime"
-                , error->message);
-}
-
-static gboolean button_press_cb (G_GNUC_UNUSED GtkStatusIcon *status_icon,
-                                 GdkEventButton *event,
-                                 G_GNUC_UNUSED gpointer user_data)
-{
-    GdkAtom atom;
-    Window xwindow;
-    Display *display;
-    XEvent xevent;
-
-    if (event->type != GDK_BUTTON_PRESS) /* double or triple click */
-        return(FALSE); /* ignore */
-    else if (event->button == 2)
-    {
-        /* send message to program to check if it is running */
-        atom = gdk_atom_intern (GLOBALTIME_RUNNING, FALSE);
-        display = gdk_x11_get_default_xdisplay ();
-        if ((xwindow = XGetSelectionOwner (display,
-                gdk_x11_atom_to_xatom(atom))) != None) { /* yes, then toggle */
-            xevent.xclient.type = ClientMessage;
-            xevent.xclient.format = 8;
-            xevent.xclient.message_type =
-                    XInternAtom (display, GLOBALTIME_TOGGLE, FALSE);
-            xevent.xclient.send_event = TRUE;
-            xevent.xclient.window = xwindow;
-
-            if (XSendEvent (display, xwindow, FALSE, NoEventMask, &xevent))
-                g_debug ("Raising GlobalTime window");
-            else
-                g_warning ("GlobalTime window raise failed");
-
-            (void)XFlush (display);
-
-            return(TRUE);
-        }
-        else { /* not running, let's try to start it. Need to reset TZ! */
-            on_globaltime_activate(NULL, NULL);
-            return(TRUE);
-        }
-    }
-
-    return(FALSE);
+    create_appt_win (NEW_APPT_WIN, cur_date, gdt);
+    g_date_time_unref (gdt);
 }
 
 static void toggle_visible_cb (G_GNUC_UNUSED GtkStatusIcon *status_icon,
@@ -192,21 +143,25 @@ static void show_menu (G_GNUC_UNUSED GtkStatusIcon *status_icon,
     gtk_menu_popup_at_pointer ((GtkMenu *)user_data, NULL);
 }
 
-static gboolean format_line (PangoLayout *pl, struct tm *t, const char *data,
+static gboolean format_line (PangoLayout *pl, GDateTime *gdt, const gchar *fmt,
                              const PangoFontDescription *desc)
 {
-    gchar row[90];
+    gchar *date_str;
 
-    if (ORAGE_STR_EXISTS(data)) {
-        if (strftime(row, sizeof (row) - 1, data, t) == 0) {
-            g_warning ("%s: strftime %s failed", G_STRFUNC, data);
+    if (ORAGE_STR_EXISTS(fmt))
+    {
+        date_str = g_date_time_format (gdt, fmt);
+        if (date_str == NULL)
+        {
+            g_warning ("%s: g_date_time_format %s failed", G_STRFUNC, fmt);
             return(FALSE);
         }
         else
         {
             pango_layout_set_font_description (pl, desc);
-            pango_layout_set_text (pl, row, -1);
+            pango_layout_set_text (pl, date_str, -1);
             pango_layout_set_alignment (pl, PANGO_ALIGN_CENTER);
+            g_free (date_str);
             return(TRUE);
         }
     }
@@ -290,7 +245,7 @@ static void create_own_icon_pango_layout (gint line,
                                           cairo_t *cr,
                                           GtkStyleContext *style_context,
                                           GtkBorder *border,
-                                          struct tm *t,
+                                          GDateTime *gdt,
                                           gint width,
                                           gint height)
 {
@@ -321,7 +276,7 @@ static void create_own_icon_pango_layout (gint line,
 
     row_x_data = get_row_x_data (line);
 
-    if (format_line (pl, t, row_x_data, font_desc) == FALSE)
+    if (format_line (pl, gdt, row_x_data, font_desc) == FALSE)
     {
         g_object_unref (pl);
         pango_font_description_free (font_desc);
@@ -360,7 +315,7 @@ static GdkPixbuf *create_dynamic_icon (void)
     const gint width = 160, height = 160; /* size of icon */
     cairo_t *cr;
     GdkPixbuf *pixbuf;
-    struct tm *t;
+    GDateTime *gdt;
     cairo_surface_t *surface;
     GtkStyleContext *style_context;
     GtkBorder border;
@@ -375,17 +330,18 @@ static GdkPixbuf *create_dynamic_icon (void)
                                   gtk_style_context_get_state (style_context),
                                   &border);
 
-    t = orage_localtime ();
+    gdt = g_date_time_new_now_local ();
     /* Date line must be first, as this background may be overlap with upper
      * or lower text areas.
      */
-    create_own_icon_pango_layout (2, cr, style_context, &border, t,
+    create_own_icon_pango_layout (2, cr, style_context, &border, gdt,
                                   width, height);
-    create_own_icon_pango_layout (1, cr, style_context, &border, t,
+    create_own_icon_pango_layout (1, cr, style_context, &border, gdt,
                                   width, height);
-    create_own_icon_pango_layout (3, cr, style_context, &border, t,
+    create_own_icon_pango_layout (3, cr, style_context, &border, gdt,
                                   width, height);
 
+    g_date_time_unref (gdt);
     g_object_unref (style_context);
     pixbuf = gdk_pixbuf_get_from_surface (surface, 0, 0, width, height);
     cairo_paint (cr);
@@ -395,41 +351,29 @@ static GdkPixbuf *create_dynamic_icon (void)
     return pixbuf;
 }
 
-GdkPixbuf *orage_create_icon(gboolean static_icon, gint size)
+static GdkPixbuf *orage_create_icon (void)
 {
     GError *error = NULL;
     GtkIconTheme *icon_theme = NULL;
-    GdkPixbuf *pixbuf, *pixbuf2;
+    GdkPixbuf *pixbuf;
 
     icon_theme = gtk_icon_theme_get_default();
-    if (static_icon)
-    { /* load static icon */
-        pixbuf = gtk_icon_theme_load_icon(icon_theme, "org.xfce.orage", size
-                , GTK_ICON_LOOKUP_USE_BUILTIN, &error);
-    }
-    else { /***** dynamic icon build starts now *****/
-        pixbuf = create_dynamic_icon ();
 
-        if (size) {
-            pixbuf2 = gdk_pixbuf_scale_simple(pixbuf, size, size
-                    , GDK_INTERP_BILINEAR);
-            g_object_unref(pixbuf);
-            pixbuf = pixbuf2;
-        }
+    pixbuf = create_dynamic_icon ();
 
-        if (pixbuf == NULL) {
-            g_warning ("%s: dynamic icon creation failed", G_STRFUNC);
-            pixbuf = gtk_icon_theme_load_icon(icon_theme, "org.xfce.orage", size
-                    , GTK_ICON_LOOKUP_USE_BUILTIN, &error);
-        }
+    if (pixbuf == NULL)
+    {
+        g_warning ("%s: dynamic icon creation failed", G_STRFUNC);
+        pixbuf = gtk_icon_theme_load_icon (icon_theme, ORAGE_APP_ID, 0,
+                                           GTK_ICON_LOOKUP_USE_BUILTIN, &error);
     }
 
     if (pixbuf == NULL) {
         g_warning ("%s: static icon creation failed, using default About icon",
                    G_STRFUNC);
         /* dynamic icon also tries static before giving up */
-        pixbuf = gtk_icon_theme_load_icon(icon_theme, "help-about", size
-                , GTK_ICON_LOOKUP_USE_BUILTIN, &error);
+        pixbuf = gtk_icon_theme_load_icon (icon_theme, "help-about", 0,
+                                           GTK_ICON_LOOKUP_USE_BUILTIN, &error);
     }
 
     if (pixbuf == NULL)
@@ -471,45 +415,37 @@ static GtkWidget *create_TrayIcon_menu(void)
     menuItem = gtk_separator_menu_item_new();
     gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
     menuItem = orage_image_menu_item(_("Quit"), "application-exit");
-    g_signal_connect(menuItem, "activate", G_CALLBACK(gtk_main_quit), NULL);
+    g_signal_connect (menuItem, "activate", G_CALLBACK (orage_quit), NULL);
     gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
 
     menuItem = gtk_separator_menu_item_new();
     gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
-    menuItem = gtk_menu_item_new_with_label(_("Globaltime"));
-    g_signal_connect(menuItem, "activate"
-            , G_CALLBACK(on_globaltime_activate), NULL);
-    gtk_menu_shell_append(GTK_MENU_SHELL(trayMenu), menuItem);
 
     gtk_widget_show_all(trayMenu);
     return(trayMenu);
 }
 
-static void destroy_TrayIcon(GtkStatusIcon *trayIcon)
-{
-    g_object_unref(trayIcon);
-}
-
-GtkStatusIcon* create_TrayIcon(GdkPixbuf *orage_logo)
+GtkStatusIcon *orage_create_trayicon (void)
 {
     CalWin *xfcal = (CalWin *)g_par.xfcal;
     GtkWidget *trayMenu;
     GtkStatusIcon *trayIcon = NULL;
+    GdkPixbuf *orage_logo;
 
-    /*
-     * Create the tray icon popup menu
-     */
-    trayMenu = create_TrayIcon_menu();
+    orage_logo = orage_create_icon ();
+    g_return_val_if_fail (orage_logo != NULL, NULL);
 
     /*
      * Create the tray icon
      */
     trayIcon = orage_status_icon_new_from_pixbuf (orage_logo);
+    g_object_unref (orage_logo);
     g_object_ref(trayIcon);
     g_object_ref_sink(trayIcon);
 
-    g_signal_connect(G_OBJECT(trayIcon), "button-press-event",
-    			   G_CALLBACK(button_press_cb), xfcal);
+    /* Create the tray icon popup menu. */
+    trayMenu = create_TrayIcon_menu();
+
     g_signal_connect(G_OBJECT(trayIcon), "activate",
     			   G_CALLBACK(toggle_visible_cb), xfcal);
     g_signal_connect(G_OBJECT(trayIcon), "popup-menu",
@@ -517,25 +453,20 @@ GtkStatusIcon* create_TrayIcon(GdkPixbuf *orage_logo)
     return(trayIcon);
 }
 
-void refresh_TrayIcon(void)
+void orage_refresh_trayicon(void)
 {
-    GdkPixbuf *orage_logo;
+    GtkStatusIcon *trayIcon;
 
-    orage_logo = orage_create_icon(FALSE, 0);
-    if (!orage_logo) {
-        return;
-    }
     if (g_par.show_systray) { /* refresh tray icon */
-        if (ORAGE_TRAYICON && orage_status_icon_is_embedded (ORAGE_TRAYICON)) {
+        if (ORAGE_TRAYICON) {
             orage_status_icon_set_visible (ORAGE_TRAYICON, FALSE);
-            destroy_TrayIcon(ORAGE_TRAYICON);
+            g_object_unref (ORAGE_TRAYICON);
         }
-        g_par.trayIcon = create_TrayIcon(orage_logo);
-        orage_status_icon_set_visible (ORAGE_TRAYICON, TRUE);
+
+        trayIcon = orage_create_trayicon ();
+        g_return_if_fail (trayIcon != NULL);
+
+        orage_status_icon_set_visible (trayIcon, TRUE);
+        g_par.trayIcon = trayIcon;
     }
-    gtk_window_set_default_icon(orage_logo);
-    /* main window is always active so we need to change it's icon also */
-    gtk_window_set_icon(GTK_WINDOW(((CalWin *)g_par.xfcal)->mWindow)
-            , orage_logo);
-    g_object_unref(orage_logo);
 }
