@@ -26,10 +26,7 @@
 
 #include <gtk/gtk.h>
 
-GdkPixbuf *orage_create_icon(gboolean static_icon, gint size);
-
-GtkStatusIcon *create_TrayIcon(GdkPixbuf *orage_logo);
-
-void refresh_TrayIcon(void);
+GtkStatusIcon *orage_create_trayicon (void);
+void orage_refresh_trayicon(void);
 
 #endif /* !__TRAY_ICON_H__ */
