@@ -17,17 +17,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-
-/* silence -Wformat-y2k warning when using %c or %x (see man strftime.3) */
-static inline size_t
-_strftime (char *s,
-           size_t max,
-           const char *fmt,
-           const struct tm *tm)
-{
-    return strftime(s, max, fmt, tm);
-}
-
 typedef struct _orage_timezone_array
 {
     int    count;     /* how many timezones we have */
